========
Examples
========

.. toctree::
   :maxdepth: 1

   example
   ensembles
   ensembles-advanced
   frequency_analysis
   customize
   extendxclim
   sdba
   sdba-advanced
   analogs
   partitioning
